pub struct BoxPool<T, const N: usize, B = CriticalSlots<N>> { /* private fields */ }Expand description
Owned-value pool — like heapless::BoxPool.
alloc writes a value into a free slot and returns a
BoxGuard. When the guard is dropped the slot is freed and T’s
destructor runs.
Obtain a &'static BoxPool via StaticBoxPool::init_pool.
Implementations